import json
import os
import requests
from requests.auth import HTTPBasicAuth
from getpass import getpass

# Function to create .m3u file with unique filename
def create_m3u_file(filename, val, key):
    base_filename, extension = os.path.splitext(filename)
    counter = 0
    new_filename = filename
    while os.path.exists(new_filename):
        new_filename = f"{base_filename}_{counter}{extension}"
        counter += 1
    content = f"#EXTM3U\n#EXTINF:-1,{val}\nhttp://{hostname}:{port}/stream/channel/{key}\n"
    with open(new_filename, 'w') as file:
        file.write(content)

# Prompt for hostname or IP address
hostname = input("Enter hostname or IP Address (default: raspberrypi.local): ") or "raspberrypi.local"

# Prompt for port number
port = input("Enter port number (default: 9981): ") or "9981"

# Prompt for username and password
username = input("Enter your username: ")
password = getpass("Enter your password: ")

# Ask user if they want to download channels with the name {name-not-set}
download_name_not_set = input("Do you want to download channels with the channel name {name-not-set}? (default: No): ").lower() in ['y', 'yes']

# Fetch JSON data from URL with basic authentication
url = f'http://{hostname}:{port}/api/channel/list'

try:
    response = requests.get(url, auth=HTTPBasicAuth(username, password))
    response.raise_for_status()  # Check for HTTP errors
    data = response.json()
except requests.exceptions.RequestException as e:
    print(f"Error fetching JSON data: {e}")
    exit(1)

# Check if data contains 'entries' key
if 'entries' not in data:
    print("Error: JSON data does not contain 'entries' key")
    exit(1)

# Create .m3u files
for item in data['entries']:
    if not isinstance(item, dict):
        print(f"Error: Item {item} is not a dictionary")
        continue
    try:
        val = item['val'].strip()
        key = item['key']
        if val == "{name-not-set}" and not download_name_not_set:
            continue
        filename = f"{val.replace(' ', '')}.m3u"
        create_m3u_file(filename, val, key)
    except KeyError as e:
        print(f"Error: Missing key {e} in item {item}")

print("M3U files created successfully!")
